Interactive data selection cursors for Matplotlib
=================================================

| |GitHub| |PyPI|
| |Read the Docs| |Build|

.. |GitHub|
   image:: https://img.shields.io/badge/github-anntzer%2Fmplcursors-brightgreen
   :target: https://github.com/anntzer/mplcursors
.. |PyPI|
   image:: https://img.shields.io/pypi/v/mplcursors.svg?color=brightgreen
   :target: https://pypi.python.org/pypi/mplcursors
.. |Read the Docs|
   image:: https://img.shields.io/readthedocs/mplcursors
   :target: https://mplcursors.readthedocs.io/en/latest/?badge=latest
.. |Build|
   image:: https://img.shields.io/github/actions/workflow/status/anntzer/mplcursors/build.yml?branch=main
   :target: https://github.com/anntzer/mplcursors/actions

mplcursors provides interactive data selection cursors for Matplotlib_.  It is
inspired from mpldatacursor_, with a much simplified API.

mplcursors requires Matplotlib_\≥3.1.

Read the documentation on `readthedocs.org`_.

As usual, install using pip:

.. code-block:: sh

   $ pip install mplcursors  # from PyPI
   $ pip install git+https://github.com/anntzer/mplcursors  # from Github

or your favorite package manager.

Run tests with pytest_.

.. _Matplotlib: https://matplotlib.org
.. _mpldatacursor: https://github.com/joferkington/mpldatacursor
.. _pytest: https://pytest.org
.. _readthedocs.org: https://mplcursors.readthedocs.org
